bayespy.inference.vmp.nodes.bernoulli.BernoulliMoments.get_converter
====================================================================

.. currentmodule:: bayespy.inference.vmp.nodes.bernoulli

.. automethod:: BernoulliMoments.get_converter